===========================================
Plata - the lean and mean Django-based Shop
===========================================

Instead of fighting against a big and all-knowing shop system, which
never does the right thing although it "only requires pushing a few
configuration buttons here and there", Plata only provides order,
payment and discount models. Building a shop on top of Django
and Plata requires programming -- but that's what we do -- programming!


Visit these sites for more information
======================================

* Plata's own website: http://www.feinheit.ch/labs/plata-django-shop/
* Documentation: http://www.feinheit.ch/media/labs/plata/
* Plata on github: http://github.com/matthiask/plata
* Once upon a time Plata came with an included product model. It is still
  available in its own repository:
  https://github.com/matthiask/plata-options-product
